#!/usr/bin/perl -w

my $filename = $0;
$filename =~ s/\.PL$//;
open OUT,">$filename" or die "Can't create $filename: $!";
chmod(0755, $filename);

my ($dictdir) = ($ARGV[0] =~ /^-dDICTDIR=(.*)/);

print OUT <<'EOF';

package Lspell;

use strict;
use Carp;
use vars qw( $VERSION @ISA @EXPORT @EXPORT_OK $SPL_DIR $errstr );

require Exporter;
require DynaLoader;

@ISA = qw( Exporter DynaLoader );
@EXPORT = qw( IGN_ALL_CAPS IGN_MIX_DIGI UDR_DISK UDR_MEMO
	langCZ langGR langSK langUK langUS
	);

$VERSION = '0.30';

bootstrap Lspell $VERSION;

use vars qw( $AUTOLOAD );
sub AUTOLOAD
	{
	my $fn = $AUTOLOAD;
	$fn =~ s/^.*:://s;
	constant($fn);
	}

package Lspell;

EOF

print OUT '$SPL_DIR = ' . "'$dictdir';\n";

print OUT <<'EOF';

spell_code('iso-lat2');
spell_init() or die "There was an error doing Lspell::spell_init()\n";

sub new
	{
	my ($class, $lang, $master, $user) = @_;
	$errstr = undef;
	unless (defined $master)
		{ $errstr = "Lspell::new must be called with language and master dictionary specified\n."; return; }

	unless ($master =~ /\.spl/) { $master .= '.spl'; }
	unless ($master =~ m!/!) { $master = "$SPL_DIR/$master"; }

	defined (my $l = spell_open_mdr($lang, $master)) or
		do { $errstr = "Error opening master dictionary $master\n"; return; };
	my $self = bless \$l, $class;
	$self->user_dictionary($user);
	$self;
	}

sub match
	{
	my ($self, $word) = @_;
	spell_check_wrd($$self, $word, 0)
	}

*similar = \&similar_words;
sub similar_words
	{
	my ($self, $word) = @_;
	spell_sim_words($$self, $word, UDR_DISK());
	}

sub user_dictionary
	{
	my ($self, $user) = @_;
	$errstr = undef;
	spell_close_udr($$self);
	if (defined $user)
		{ spell_open_udr($$self, $user) or do { $errstr = "Error opening user dictionary $user\n"; return; }; }
	1;
	}

END
	{ spell_done(); }
1;

__END__

=head1 NAME

Lspell - Access to Sevecek's spell library

=head1 SYNOPSIS

	use Lspell;
	my $spell = new Lspell langCZ, '/home/user/cz.spl';
	if ($spell->match('Krtek')) { ... }
	my @similar = $spell->similar_words('Krtek');

=head1 DESCRIPTION

This module provides access to spellchecking library by Pavel Sevecek.
To use the library, you have to create an object using the B<new> call.
The first parameter must be the language specification, currently one
of

	langCZ langGR langSK langUK langUS

The second parameter is a name of the master dictionary. If there is
no directory in the path, that from the default location will be used,
so it's possible to do

	my $spell = new Lspell langCZ, 'cz.spl';

The optional third parameter specifies the user dictionary, this has
to be the complete path.

After you've created the object, the following methods are available:

=over 4

=item match

Takes one argument, the word to match, returns true or undef.

=item similar_words

Takes a word as an argument, returns list of similar words.

=item user_dictionary

Specifies the user dictionary even after new. You can also call this
without a paramater, then it will close previously used user
dictionary.

Note, that you cannot change the master dictionary for the object. For
that you need to create a new object even if it's a spell object for
the same language (Pary, is this correct?)

=back

=head1 Exported constants

(Note: currently unused):

  IGN_ALL_CAPS
  IGN_MIX_DIGI
  UDR_DISK
  UDR_MEMO

=head1 VERSION

0.30

=head1 SEE ALSO

perl(1).

=head1 AUTHOR

(c) 1998 Jan Pazdziora <adelton@fi.muni.cz>,
http://www.fi.muni.cz/~adelton/ at Faculty of Informatics, Masaryk
University, Brno, Czech Republic

=cut

EOF

